#!/bin/bash

#DEBUG=1
MAXRAND=32768
DURATION=60

#### SOME SAFE DEFAULTS ####
TIMESTEP=1
CONFIGFILE="../simulate_user/config"
URLFILE="../simulate_user/urls.txt"

COMMAND[0]="no_op"
WEIGHT[0]=248

COMMAND[1]="load_random_url"
WEIGHT[1]=7

COMMAND[2]="close_browser"
WEIGHT[2]=1
#### END DEFAULTS ####


# perhaps later use random number generator from
# http://www.shelldorado.com/newsletter/issues/2002-3-Aug.html
# bash $RANDOM is on 0-32767
function make_random() {
	rand=$RANDOM
}

function calculate_weightings() {
	local i=0
	local divisor=0
	while [ ! -z ${COMMAND[$i]} ]
	do
		divisor=$(( $divisor + ${WEIGHT[$i]} ))
		i=$(( $i + 1 ))
	done
	i=0
	last_index=0
	while [ ! -z ${COMMAND[$i]} ]
	do
		INDEX[$i]=$(( $last_index + ${WEIGHT[$i]} * $MAXRAND / $divisor ))
		last_index=${INDEX[$i]}
		[ ! -z "$DEBUG" ] && echo "${COMMAND[$i]} $last_index"
		i=$(( $i + 1 ))
		
	done
}

# pick one url from the file
function get_random_url() {
	make_random
	local num=`wc -l $URLFILE | cut -f 1 -d " "`
	local line_number=$(( $rand % $num ))
	url=`head -$line_number $URLFILE | tail -1` 
}

function load_random_url() {
	get_random_url
	echo "loading $url"
	if firefox -remote "ping()" &>/dev/null
	then
		firefox -remote "openurl($url,new-tab)"
	else 
		firefox $url &
		sleep 10
	fi
}

function close_browser() {
	echo "Stopping Firefox"
	if firefox -remote "ping()"
	then
		killall -HUP firefox-bin
		[ -e $HOME/.mozilla/firefox/*.default/sessionstore.js ] && rm $HOME/.mozilla/firefox/*.default/sessionstore.js
	fi
} 

# is it possible to reboot a thin client in a script?
# ssh server on thin clients would be one way
function reboot() {
	local a=b
}

function no_op() {
	/bin/true
	#echo "no op"
}

# load the config file
if [ -r $CONFIGFILE ]
then
	source $CONFIGFILE
else
	echo "Couldn't load config"
	exit 
fi

# check the url file is readable
if [ ! -r "$URLFILE" ]
then
	echo "Couldn't open $URLFILE"
	exit 
fi

calculate_weightings

START_TIME=`date +%s`
CUR_TIME=`date +%s`
while [ $(($CUR_TIME - $START_TIME )) -lt $DURATION  ]
do
	sleep $TIMESTEP
	make_random
	j=0; k=0
	while [ ! -z ${COMMAND[$j]} ] && [ $k -lt 1 ]
	do
		if [ ${INDEX[$j]} -gt $rand ]
		then	
			[ ! -z "$DEBUG" ] && echo "$j: running ${COMMAND[$j]} $rand"
			eval ${COMMAND[$j]}
			k=1
		fi
		j=$(( $j + 1 ))
	done
	CUR_TIME=`date +%s`
done

# cleanup firefox if necessary
[ -e $HOME/.mozilla/firefox/*.default/sessionstore.js ] && rm $HOME/.mozilla/firefox/*.default/sessionstore.js

echo "$DURATION passed, all done!"

